package Universe::ObservableUniverse::Filament::SuperCluster::Cluster::Group::Galaxy::Arm::Bubble::InterstellarCloud::SolarSystem::Earth;

=head1 NAME

Universe::ObservableUniverse::Filament::SuperCluster::Cluster::Group::Galaxy::Arm::Bubble::InterstellarCloud::SolarSystem::Earth

=head1 DESCRIPTION

Mostly harmless

=head1 SYNOPSIS

    use print Universe::ObservableUniverse::Filament::SuperCluster::Cluster::Group::Galaxy::Arm::Bubble::InterstellarCloud::SolarSystem::Earth;
    
    print Universe::ObservableUniverse::Filament::SuperCluster::Cluster::Group::Galaxy::Arm::Bubble::InterstellarCloud::SolarSystem::Earth->info, "\n";
    print Universe::ObservableUniverse::Filament::SuperCluster::Cluster::Group::Galaxy::Arm::Bubble::InterstellarCloud::SolarSystem::Earth->ultimate_answer, "\n";

=cut

use warnings;
use strict;

our $VERSION = '0.03';

=head1 METHODS

Any

=cut

sub AUTOLOAD {
    return 'Mostly harmless';
}

=head2 ultimate_answer

ultimate answer to the ultimate question

=cut

sub ultimate_answer {
    return 42;
}

42;


__END__

=head1 SEE ALSO

L<aliased>

=head1 CREDITS

Thanks to Pauline Barmby from University of Western Ontario for helping
me to find out the right location path.

=head1 AUTHOR

Jozef Kutej

=head1 COPYRIGHT

:)

=cut
